=================================
 Documentation: caldav |release|
=================================

This is the Python CalDAV client library, making communication with calendaring servers easy.

NOTE: version 3 introduces quite some new API.  The documentation has been AI-maintained to reflect this, causing two potential problems:

* The quality of the doc may be varying.  I will get back to it and do proper QA on the documentation when I have my hands free.
* This is the v3-documentation.  If you're stuck on v2, then quite some of the instructions in this documentation will not work for you.

Upgrading from v2?  See :doc:`v3-migration`.

Contents
========

.. toctree::
   :maxdepth: 1

   about
   v3-migration
   tutorial
   async
   jmap
   howtos
   performance
   reference
   examples
   contact

====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
